tiled.client.dataframe.DataFrameClient.read\_partition
======================================================

.. currentmodule:: tiled.client.dataframe

.. automethod:: DataFrameClient.read_partition